/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.extension.model;

import org.apache.commons.lang3.ArrayUtils;

import com.github.htfv.maven.plugins.buildconfigurator.model.BCBuild;
import com.github.htfv.maven.plugins.buildconfigurator.model.BCDependency;
import com.github.htfv.maven.plugins.buildconfigurator.model.BCExtensionModel;
import com.github.htfv.maven.plugins.buildconfigurator.model.BCPropertyFile;

/**
 * Default implementation of the Build Configurator Extension model.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class BCExtensionModelImpl implements BCExtensionModel
{
    /**
     * Build information which shall be merged into the project.
     */
    private BCBuild build;

    /**
     * Default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     */
    private String defaultPropertyFilesEncoding;

    /**
     * Array of dependencies which shall be merged into the project.
     */
    private BCDependency[] dependencies;

    /**
     * Flag indicating whether the plugin should be quiet when a property file
     * is not found.
     */
    private String ignoreMissingPropertyFiles;

    /**
     * Array of property files whose properties shall be merged into the
     * project.
     */
    private BCPropertyFile[] propertyFiles;

    /**
     * Flag indicating whether build configuration should be bypassed.
     */
    private String skip;

    @Override
    public BCBuild getBuild()
    {
        return build;
    }

    /**
     * Gets default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     *
     * @return default character encoding used to read property files.
     */
    @Override
    public String getDefaultPropertyFilesEncoding()
    {
        return defaultPropertyFilesEncoding;
    }

    @Override
    public BCDependency[] getDependencies()
    {
        return ArrayUtils.clone(dependencies);
    }

    /**
     * Gets the flag indicating whether the plugin should be quiet when a
     * property file is not found.
     *
     * @return flag indicating whether the plugin should be quiet.
     */
    @Override
    public String getIgnoreMissingPropertyFiles()
    {
        return ignoreMissingPropertyFiles;
    }

    @Override
    public BCPropertyFile[] getPropertyFiles()
    {
        return ArrayUtils.clone(propertyFiles);
    }

    @Override
    public String getSkip()
    {
        return skip;
    }

    @Override
    public void setBuild(final BCBuild build)
    {
        this.build = build;
    }

    @Override
    public void setDefaultPropertyFilesEncoding(final String defaultPropertyFilesEncoding)
    {
        this.defaultPropertyFilesEncoding = defaultPropertyFilesEncoding;
    }

    @Override
    public void setDependencies(final BCDependency[] dependencies)
    {
        this.dependencies = ArrayUtils.clone(dependencies);
    }

    @Override
    public void setIgnoreMissingPropertyFiles(final String ignoreMissingPropertyFiles)
    {
        this.ignoreMissingPropertyFiles = ignoreMissingPropertyFiles;
    }

    @Override
    public void setPropertyFiles(final BCPropertyFile[] propertyFiles)
    {
        this.propertyFiles = ArrayUtils.clone(propertyFiles);
    }

    @Override
    public void setSkip(final String skip)
    {
        this.skip = skip;
    }
}
